summaryrefslogtreecommitdiffstats
path: root/usr.sbin/sade/system.c
diff options
context:
space:
mode:
authorjkh <jkh@FreeBSD.org>1997-04-28 10:31:14 +0000
committerjkh <jkh@FreeBSD.org>1997-04-28 10:31:14 +0000
commitb980a85e29b969dcfd9d5fe263bab80066c383fb (patch)
tree2c39d7e1e2c0589d47c08214daaa385e1a1abbe6 /usr.sbin/sade/system.c
parenta82625370f99b33d357ac2754cdb659c8fa8d81c (diff)
downloadFreeBSD-src-b980a85e29b969dcfd9d5fe263bab80066c383fb.zip
FreeBSD-src-b980a85e29b969dcfd9d5fe263bab80066c383fb.tar.gz
Adapt to rc.conf file format.
Diffstat (limited to 'usr.sbin/sade/system.c')
-rw-r--r--usr.sbin/sade/system.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/usr.sbin/sade/system.c b/usr.sbin/sade/system.c
index b66928b..dfbe453 100644
--- a/usr.sbin/sade/system.c
+++ b/usr.sbin/sade/system.c
@@ -4,7 +4,7 @@
* This is probably the last program in the `sysinstall' line - the next
* generation being essentially a complete rewrite.
*
- * $Id: system.c,v 1.78 1997/04/28 06:15:49 jkh Exp $
+ * $Id: system.c,v 1.79 1997/04/28 09:35:59 jkh Exp $
*
* Jordan Hubbard
*
@@ -118,9 +118,9 @@ systemShutdown(int status)
if (status >=0 && mediaDevice)
mediaDevice->shutdown(mediaDevice);
- /* write out any changes to sysconfig .. */
- if (!status)
- configSysconfig("/etc/sysconfig");
+ /* write out any changes to rc.conf .. */
+ if (status)
+ configRC_conf("/etc/rc.conf");
/* Shut down the dialog library */
if (DialogActive) {
OpenPOWER on IntegriCloud